from setuptools import setup

setup(name='analyze-sqs-queue',
      version='0.0.2',
      description='Toll that can be used to collect and display information about SQS queue and messages in it',
      url='https://repo.lcloud.pl/mgmt/amazon-sqs/analyze-sqs-queue',
      author='Oleg Dubyk',
      author_email='oleg.dubyk@lcloud.pl',
      license='MIT',
      #packages=['analyze-sqs-queue'],
      install_requires=[
          'boto3',
      ],
      scripts=[
          'bin/analyze-sqs-queue'
      ],
      zip_safe=True)
